﻿using System;
using System.IO;
using System.Web.Mvc;
using SampleBackend.Models;

namespace SampleBackend.Controllers
{
  public class DashboardDataController : Controller
  {
    [HttpPost]
    public ActionResult Data()
    {
      var req = Request.InputStream;
      req.Seek(0, System.IO.SeekOrigin.Begin);
      string json = new StreamReader(req).ReadToEnd();
      
      var command = DashboardJson.DeserializeObject<DashboardCommand>(json);

      if (command.Command == "ExecuteQuery")
      {
        if (command.QueryString == tableQuery)
        {
          return Content(tableResponse);
        }
        
        if (command.QueryString == columnQuery)
        {
          return Content(columnResponse);
        }

        if (command.QueryString == routineQuery)
        {
          return Content(routineResponse);
        }

        throw new NotImplementedException("Never called by stimulsoft");
      }

      throw new NotImplementedException("Never called by stimulsoft");
    }

    
    private const string tableQuery = "SELECT TABLE_NAME, TABLE_TYPE, TABLE_SCHEMA FROM INFORMATION_SCHEMA.TABLES";

    private const string tableResponse =
      @"{
  ""success"": true,
  ""notice"": null,
  ""columns"": [
    ""TABLE_NAME"",
    ""TABLE_TYPE"",
    ""TABLE_SCHEMA""
  ],
  ""rows"": [
    [
      ""Assessment"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""WoundState"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""Measurement"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""Note"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""DimDate"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""AssessmentTypeVersion"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""AttributeType"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""WoundStateType"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""Unit"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""Patient"",
      ""BASE TABLE"",
      ""rpt""
    ],
    [
      ""Wound"",
      ""BASE TABLE"",
      ""rpt""
    ]
  ],
  ""types"": [
    ""string"",
    ""string"",
    ""string""
  ],
  ""adapterVersion"": ""2024.2.3"",
  ""handlerVersion"": ""2024.2.3"",
  ""checkVersion"": true
}";

    private const string columnQuery =
      "SELECT TABLE_NAME, COLUMN_NAME, DATA_TYPE FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME='Assessment' OR TABLE_NAME='WoundState' OR TABLE_NAME='Measurement' OR TABLE_NAME='Note' OR TABLE_NAME='DimDate' OR TABLE_NAME='AssessmentTypeVersion' OR TABLE_NAME='AttributeType' OR TABLE_NAME='WoundStateType' OR TABLE_NAME='Unit' OR TABLE_NAME='Patient' OR TABLE_NAME='Wound'";

    private const string columnResponse =
      @"{
  ""success"": true,
  ""notice"": null,
  ""columns"": [
    ""TABLE_NAME"",
    ""COLUMN_NAME"",
    ""DATA_TYPE""
  ],
  ""rows"": [
    [
      ""Assessment"",
      ""id"",
      ""string""
    ],
    [
      ""Assessment"",
      ""patientFk"",
      ""string""
    ],
    [
      ""Assessment"",
      ""woundFk"",
      ""string""
    ],
    [
      ""Assessment"",
      ""unitFk"",
      ""string""
    ],
    [
      ""Assessment"",
      ""date"",
      ""datetimeoffset""
    ],
    [
      ""Assessment"",
      ""timeZoneId"",
      ""nvarchar""
    ],
    [
      ""Assessment"",
      ""dimDateFk"",
      ""int""
    ],
    [
      ""Assessment"",
      ""assessmentTypeVersionFk"",
      ""string""
    ],
    [
      ""Assessment"",
      ""createdByUserFk"",
      ""string""
    ],
    [
      ""Assessment"",
      ""createdByUserName"",
      ""nvarchar""
    ],
    [
      ""Assessment"",
      ""signedByUserFk"",
      ""string""
    ],
    [
      ""Assessment"",
      ""signedByUserName"",
      ""nvarchar""
    ],
    [
      ""AssessmentTypeVersion"",
      ""id"",
      ""string""
    ],
    [
      ""AssessmentTypeVersion"",
      ""name"",
      ""nvarchar""
    ],
    [
      ""AssessmentTypeVersion"",
      ""assessmentTypeId"",
      ""string""
    ],
    [
      ""AssessmentTypeVersion"",
      ""definitionVersion"",
      ""int""
    ],
    [
      ""AssessmentTypeVersion"",
      ""orderIndex"",
      ""int""
    ],
    [
      ""AssessmentTypeVersion"",
      ""type"",
      ""int""
    ],
    [
      ""AttributeType"",
      ""id"",
      ""string""
    ],
    [
      ""AttributeType"",
      ""name"",
      ""nvarchar""
    ],
    [
      ""AttributeType"",
      ""variableName"",
      ""nvarchar""
    ],
    [
      ""AttributeType"",
      ""attributeTypeKey"",
      ""string""
    ],
    [
      ""AttributeType"",
      ""orderIndex"",
      ""int""
    ],
    [
      ""AttributeType"",
      ""dataType"",
      ""int""
    ],
    [
      ""DimDate"",
      ""id"",
      ""int""
    ],
    [
      ""DimDate"",
      ""date"",
      ""date""
    ],
    [
      ""DimDate"",
      ""dayOfWeek"",
      ""int""
    ],
    [
      ""DimDate"",
      ""dayOfMonth"",
      ""int""
    ],
    [
      ""DimDate"",
      ""dayOfYear"",
      ""int""
    ],
    [
      ""DimDate"",
      ""month"",
      ""int""
    ],
    [
      ""DimDate"",
      ""quarter"",
      ""int""
    ],
    [
      ""DimDate"",
      ""year"",
      ""int""
    ],
    [
      ""DimDate"",
      ""firstOfMonth"",
      ""date""
    ],
    [
      ""DimDate"",
      ""weekOfYear"",
      ""int""
    ],
    [
      ""Measurement"",
      ""id"",
      ""string""
    ],
    [
      ""Measurement"",
      ""assessmentFk"",
      ""string""
    ],
    [
      ""Measurement"",
      ""dimDateFk"",
      ""int""
    ],
    [
      ""Measurement"",
      ""woundFk"",
      ""string""
    ],
    [
      ""Measurement"",
      ""patientFk"",
      ""string""
    ],
    [
      ""Measurement"",
      ""attributeTypeFk"",
      ""string""
    ],
    [
      ""Measurement"",
      ""unitFk"",
      ""string""
    ],
    [
      ""Measurement"",
      ""area"",
      ""float""
    ],
    [
      ""Measurement"",
      ""areaReduction"",
      ""float""
    ],
    [
      ""Measurement"",
      ""perimeter"",
      ""float""
    ],
    [
      ""Measurement"",
      ""depth"",
      ""float""
    ],
    [
      ""Measurement"",
      ""volume"",
      ""float""
    ],
    [
      ""Measurement"",
      ""length"",
      ""float""
    ],
    [
      ""Measurement"",
      ""width"",
      ""float""
    ],
    [
      ""Measurement"",
      ""imageCount"",
      ""int""
    ],
    [
      ""Measurement"",
      ""outlineCount"",
      ""int""
    ],
    [
      ""Measurement"",
      ""islandCount"",
      ""int""
    ],
    [
      ""Note"",
      ""id"",
      ""string""
    ],
    [
      ""Note"",
      ""attributeTypeFk"",
      ""string""
    ],
    [
      ""Note"",
      ""patientFk"",
      ""string""
    ],
    [
      ""Note"",
      ""unitFk"",
      ""string""
    ],
    [
      ""Note"",
      ""dimDateFk"",
      ""int""
    ],
    [
      ""Note"",
      ""assessmentFk"",
      ""string""
    ],
    [
      ""Note"",
      ""woundFk"",
      ""string""
    ],
    [
      ""Note"",
      ""woundStateFk"",
      ""string""
    ],
    [
      ""Note"",
      ""value"",
      ""nvarchar""
    ],
    [
      ""Note"",
      ""valueInt"",
      ""int""
    ],
    [
      ""Note"",
      ""valueDecimal"",
      ""decimal""
    ],
    [
      ""Note"",
      ""valueDate"",
      ""datetime""
    ],
    [
      ""Note"",
      ""valueBoolean"",
      ""bit""
    ],
    [
      ""Patient"",
      ""id"",
      ""string""
    ],
    [
      ""Patient"",
      ""domainId"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""firstName"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""middleName"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""lastName"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""dateOfBirth"",
      ""datetime""
    ],
    [
      ""Patient"",
      ""addressStreet"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""addressSuburb"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""addressCity"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""addressState"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""addressPostcode"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""addressCountry"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""workPhone"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""homePhone"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""mobilePhone"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""gender"",
      ""nvarchar""
    ],
    [
      ""Patient"",
      ""unitFk"",
      ""string""
    ],
    [
      ""Unit"",
      ""id"",
      ""string""
    ],
    [
      ""Unit"",
      ""name"",
      ""nvarchar""
    ],
    [
      ""Wound"",
      ""id"",
      ""string""
    ],
    [
      ""Wound"",
      ""patientFk"",
      ""string""
    ],
    [
      ""Wound"",
      ""unitFk"",
      ""string""
    ],
    [
      ""Wound"",
      ""baselineDate"",
      ""datetime""
    ],
    [
      ""Wound"",
      ""baselineDimDateFk"",
      ""int""
    ],
    [
      ""Wound"",
      ""index"",
      ""int""
    ],
    [
      ""Wound"",
      ""label"",
      ""nvarchar""
    ],
    [
      ""Wound"",
      ""level0AnatomyId"",
      ""string""
    ],
    [
      ""Wound"",
      ""level0Text"",
      ""nvarchar""
    ],
    [
      ""Wound"",
      ""level1AnatomyId"",
      ""string""
    ],
    [
      ""Wound"",
      ""level1Text"",
      ""nvarchar""
    ],
    [
      ""Wound"",
      ""level2AnatomyId"",
      ""string""
    ],
    [
      ""Wound"",
      ""level2Text"",
      ""nvarchar""
    ],
    [
      ""Wound"",
      ""level3AnatomyId"",
      ""string""
    ],
    [
      ""Wound"",
      ""level3Text"",
      ""nvarchar""
    ],
    [
      ""Wound"",
      ""anatomyLabel"",
      ""nvarchar""
    ],
    [
      ""Wound"",
      ""auxText"",
      ""nvarchar""
    ],
    [
      ""Wound"",
      ""description"",
      ""nvarchar""
    ],
    [
      ""WoundState"",
      ""id"",
      ""string""
    ],
    [
      ""WoundState"",
      ""woundFk"",
      ""string""
    ],
    [
      ""WoundState"",
      ""patientFk"",
      ""string""
    ],
    [
      ""WoundState"",
      ""assessmentFk"",
      ""string""
    ],
    [
      ""WoundState"",
      ""unitFk"",
      ""string""
    ],
    [
      ""WoundState"",
      ""woundStateTypeFk"",
      ""string""
    ],
    [
      ""WoundState"",
      ""startDate"",
      ""datetime""
    ],
    [
      ""WoundState"",
      ""startDateDimDateFk"",
      ""int""
    ],
    [
      ""WoundState"",
      ""endDate"",
      ""datetime""
    ],
    [
      ""WoundState"",
      ""endDateDimDateFk"",
      ""int""
    ],
    [
      ""WoundState"",
      ""isCurrentState"",
      ""bit""
    ],
    [
      ""WoundStateType"",
      ""id"",
      ""string""
    ],
    [
      ""WoundStateType"",
      ""name"",
      ""nvarchar""
    ],
    [
      ""WoundStateType"",
      ""attributeLookupKey"",
      ""string""
    ],
    [
      ""WoundStateType"",
      ""isActive"",
      ""bit""
    ]
  ],
  ""types"": [
    ""string"",
    ""string"",
    ""string""
  ],
  ""adapterVersion"": ""2024.2.3"",
  ""handlerVersion"": ""2024.2.3"",
  ""checkVersion"": true
}";

    private const string routineQuery =
      "SELECT ROUTINE_NAME FROM INFORMATION_SCHEMA.ROUTINES WHERE ROUTINE_TYPE='PROCEDURE'";

    private const string routineResponse = @"{
  ""success"": true,
  ""notice"": null,
  ""columns"": [
    ""ROUTINE_NAME""
  ],
  ""rows"": [],
  ""types"": [
    ""string""
  ],
  ""adapterVersion"": ""2024.2.3"",
  ""handlerVersion"": ""2024.2.3"",
  ""checkVersion"": true
}";
  }
}